.. RayOptics documentation master file, created by
   sphinx-quickstart on Fri Sep 14 13:29:37 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

:tocdepth: 4

#######################
RayOptics Documentation
#######################

.. image:: DBGauss.png
   :align: center

.. toctree::
   :maxdepth: 1
   :caption: Contents

   Introduction

.. _getting-started:

.. toctree::
   :maxdepth: 1
   :caption: Getting Started

   install
   userguide/interactive
   userguide/qt
   examples/TripletExample
   examples/EdmundLensImport/EdmundLensImport

.. _user-docs:

.. toctree::
   :maxdepth: 1
   :caption: User Guide

   userguide/models
   userguide/calc
   userguide/gui

.. _dev-guide:

.. toctree::
   :maxdepth: 3
   :caption: Developer Guide

   Module Reference <api/modules>

.. _misc-items:

.. toctree::
   :maxdepth: 1
   :caption: Miscellaneous

   Authors <authors>
   License <license>
   Changelog <changelog>

*****
Index
*****

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
